@@ -52,12 +52,12 @@ class ResourcesControllerPlugins extends Hubzero_Controller
 			JRequest::setVar('action', $task);
 			JRequest::setVar('task', 'manage');
 		}
-
+		
 		$this->_folder = 'resources';
-
+		
 		parent::execute();
 	}
-
+	
 	/**
 	 * List resource types
 	 * 
@@ -66,7 +66,7 @@ class ResourcesControllerPlugins extends Hubzero_Controller
 	public function displayTask()
 	{
 		// Get configuration
-		$app = JFactory::getApplication();
+		$app =& JFactory::getApplication();
 		$config = JFactory::getConfig();
 
 		// Incoming
@@ -93,7 +93,6 @@ class ResourcesControllerPlugins extends Hubzero_Controller
 			'filter_order_Dir',
 			'ASC'
 		));
-		
 		$this->view->filters['state']    = $app->getUserStateFromRequest(
 			$this->_option . '.' . $this->_controller . '.state',
 			'state',
@@ -106,7 +105,7 @@ class ResourcesControllerPlugins extends Hubzero_Controller
 			'',
 			'word'
 		));
-
+		
 		$where = array();
 		$this->client = JRequest::getWord('filter_client', 'site');
 
@@ -195,26 +194,11 @@ class ResourcesControllerPlugins extends Hubzero_Controller
 			JError::raiseError(500, $this->database->stderr());
 			return false;
 		}
-
-		$lang = JFactory::getLanguage();
-		if ($this->view->rows)
-		{
-			foreach ($this->view->rows as &$item) 
-			{
-				$source = JPATH_PLUGINS . '/' . $item->folder . '/' . $item->element;
-				$extension = 'plg_' . $item->folder . '_' . $item->element;
-					$lang->load($extension . '.sys', JPATH_ADMINISTRATOR, null, false, false)
-				||	$lang->load($extension . '.sys', $source, null, false, false)
-				||	$lang->load($extension . '.sys', JPATH_ADMINISTRATOR, $lang->getDefault(), false, false)
-				||	$lang->load($extension . '.sys', $source, $lang->getDefault(), false, false);
-				$item->name = JText::_($item->name);
-			}
-		}
-
+		
 		// Get related plugins
-		JPluginHelper::importPlugin('resources');
-		$dispatcher = JDispatcher::getInstance();
-
+		JPluginHelper::importPlugin($this->_folder);
+		$dispatcher =& JDispatcher::getInstance();
+		
 		// Show related content
 		$this->view->manage = $dispatcher->trigger('onCanManage');
 
@@ -225,10 +209,7 @@ class ResourcesControllerPlugins extends Hubzero_Controller
 		// Set any errors
 		if ($this->getError())
 		{
-			foreach ($this->getErrors() as $error)
-			{
-				$this->view->setError($error);
-			}
+			$this->view->setError($this->getError());
 		}
 
 		// Output the HTML
@@ -255,8 +236,8 @@ class ResourcesControllerPlugins extends Hubzero_Controller
 		}
 
 		// Get related plugins
-		JPluginHelper::importPlugin('resources', $plugin);
-		$dispatcher = JDispatcher::getInstance();
+		JPluginHelper::importPlugin($this->_folder, $plugin);
+		$dispatcher =& JDispatcher::getInstance();
 		
 		// Show related content
 		$out = $dispatcher->trigger(
@@ -336,10 +317,21 @@ class ResourcesControllerPlugins extends Hubzero_Controller
 			$cid = JRequest::getVar('cid', array(0), '', 'array');
 			JArrayHelper::toInteger($cid, array(0));
 			
-			$this->view->row = JTable::getInstance('plugin');
+			if (version_compare(JVERSION, '1.6', 'ge'))
+			{
+				$this->view->row = JTable::getInstance('extension');
+			}
+			else
+			{
+				$this->view->row = JTable::getInstance('plugin');
+			}
 
 			// load the row from the db table
 			$this->view->row->load($cid[0]);
+			if (version_compare(JVERSION, '1.6', 'ge'))
+			{
+				$this->view->row->published = $this->view->row->enabled;
+			}
 		}
 		
 		// Is this entry checked out?
@@ -370,7 +362,7 @@ class ResourcesControllerPlugins extends Hubzero_Controller
 		{
 			$this->view->row->checkout($this->juser->get('id'));
 
-			$lang = JFactory::getLanguage();
+			$lang =& JFactory::getLanguage();
 			$lang->load('plg_' . trim($this->view->row->folder) . '_' . trim($this->view->row->element), JPATH_ADMINISTRATOR);
 
 			$data = JApplicationHelper::parseXMLInstallFile(JPATH_SITE . DS . 'plugins' . DS  .$this->view->row->folder . DS . $this->view->row->element . '.xml');
@@ -389,15 +381,28 @@ class ResourcesControllerPlugins extends Hubzero_Controller
 		if ($this->view->row->ordering > -10000 && $this->view->row->ordering < 10000)
 		{
 			// build the html select list for ordering
-			$query = 'SELECT ordering AS value, name AS text'
-				. ' FROM #__plugins'
-				. ' WHERE folder = '.$this->database->Quote($this->_folder)
-				. ' AND published > 0'
-				. ' AND '. ($client == 'admin' ? "client_id='1'" : "client_id='0'")
-				. ' AND ordering > -10000'
-				. ' AND ordering < 10000'
-				. ' ORDER BY ordering'
-			;
+			if (version_compare(JVERSION, '1.6', 'ge'))
+			{
+				$query = 'SELECT ordering AS value, name AS text'
+					. ' FROM #__extensions'
+					. ' WHERE type='.$this->database->Quote('plugin').' AND folder = '.$this->database->Quote($this->_folder)
+					. ' AND enabled > 0'
+					. ' AND '. ($client == 'admin' ? "client_id='1'" : "client_id='0'")
+					. ' AND ordering > -10000'
+					. ' AND ordering < 10000'
+					. ' ORDER BY ordering';
+			}
+			else
+			{
+				$query = 'SELECT ordering AS value, name AS text'
+					. ' FROM #__plugins'
+					. ' WHERE folder = '.$this->database->Quote($this->_folder)
+					. ' AND published > 0'
+					. ' AND '. ($client == 'admin' ? "client_id='1'" : "client_id='0'")
+					. ' AND ordering > -10000'
+					. ' AND ordering < 10000'
+					. ' ORDER BY ordering';
+			}
 			$order = JHTML::_('list.genericordering',  $query);
 			
 			$this->view->lists['ordering'] = JHTML::_('select.genericlist', $order, 'ordering', 'class="inputbox" size="1"', 'value', 'text', intval($this->view->row->ordering));
@@ -410,10 +415,10 @@ class ResourcesControllerPlugins extends Hubzero_Controller
 		$this->view->lists['published'] = JHTML::_('select.booleanlist', 'published', 'class="inputbox"', $this->view->row->published);
 
 		$paramsClass = 'JParameter';
-		if (version_compare(JVERSION, '1.6', 'ge'))
+		/*if (version_compare(JVERSION, '1.6', 'ge'))
 		{
 			$paramsClass = 'JRegistry';
-		}
+		}*/
 
 		$this->view->params = new $paramsClass(
 			$this->view->row->params, 
@@ -447,14 +452,7 @@ class ResourcesControllerPlugins extends Hubzero_Controller
 		$client = JRequest::getWord('filter_client', 'site');
 
 		// Bind data
-		if (version_compare(JVERSION, '1.6', 'lt')) 
-		{
-			$row = JTable::getInstance('plugin');
-		}
-		else
-		{
-			$row = JTable::getInstance('extension');
-		}
+		$row =& JTable::getInstance('plugin');
 		if (!$row->bind(JRequest::get('post'))) 
 		{
 			$this->addComponentMessage($row->getError(), 'error');
@@ -538,7 +536,7 @@ class ResourcesControllerPlugins extends Hubzero_Controller
 	public function stateTask($state=0)
 	{
 		// Check for request forgeries
-		JRequest::checkToken() or JRequest::checkToken('get') or jexit('Invalid Token');
+		JRequest::checkToken('get') or jexit('Invalid Token');
 
 		// Incoming
 		$id = JRequest::getVar('id', array(0), '', 'array');
@@ -557,18 +555,9 @@ class ResourcesControllerPlugins extends Hubzero_Controller
 			return;
 		}
 
-		if (version_compare(JVERSION, '1.6', 'lt')) 
-		{
-			$query = 'UPDATE #__plugins SET published = '.(int) $state
-				. ' WHERE id IN (' . implode(',', $id) . ')'
-				. ' AND (checked_out = 0 OR (checked_out = '.(int) $this->juser->get('id').'))';
-		}
-		else 
-		{
-			$query = "UPDATE #__extensions SET enabled = ".(int) $state
-				. " WHERE extension_id IN (" . implode(',', $id) . ")"
-				. " AND `type`='plugin' AND (checked_out = 0 OR (checked_out = ". (int) $this->juser->get('id') . "))";
-		}
+		$query = 'UPDATE #__plugins SET published = '.(int) $state
+			. ' WHERE id IN (' . implode(',', $id) . ')'
+			. ' AND (checked_out = 0 OR (checked_out = '.(int) $this->juser->get('id').'))';
 
 		$this->database->setQuery($query);
 		if (!$this->database->query()) 
@@ -583,14 +572,7 @@ class ResourcesControllerPlugins extends Hubzero_Controller
 
 		if (count($id) == 1) 
 		{
-			if (version_compare(JVERSION, '1.6', 'lt'))
-			{
-				$row = JTable::getInstance('plugin');
-			}
-			else
-			{
-				$row = JTable::getInstance('extension');
-			}
+			$row =& JTable::getInstance('plugin');
 			$row->checkin($id[0]);
 		}
 
@@ -598,27 +580,7 @@ class ResourcesControllerPlugins extends Hubzero_Controller
 			'index.php?option=' . $this->_option . '&controller=' . $this->_controller . '&client=' . $client
 		);
 	}
-
-	/**
-	 * Reorder a plugin up
-	 * 
-	 * @return     void
-	 */
-	public function orderupTask()
-	{
-		return $this->orderTask();
-	}
-
-	/**
-	 * Reorder a plugin down
-	 * 
-	 * @return     void
-	 */
-	public function orderdownTask()
-	{
-		return $this->orderTask();
-	}
-
+	
 	/**
 	 * Reorder a plugin
 	 * 
@@ -628,9 +590,9 @@ class ResourcesControllerPlugins extends Hubzero_Controller
 	public function orderTask()
 	{
 		// Check for request forgeries
-		JRequest::checkToken() or JRequest::checkToken('get') or jexit('Invalid Token');
+		JRequest::checkToken() or jexit('Invalid Token');
 
-		$cid 	= JRequest::getVar('id', array(0), 'post', 'array');
+		$cid 	= JRequest::getVar('cid', array(0), 'post', 'array');
 		JArrayHelper::toInteger($cid, array(0));
 
 		$uid    = $cid[0];
@@ -647,14 +609,7 @@ class ResourcesControllerPlugins extends Hubzero_Controller
 			$where = "client_id = 0";
 		}
 		
-		if (version_compare(JVERSION, '1.6', 'lt')) 
-		{
-			$row = JTable::getInstance('plugin');
-		}
-		else
-		{
-			$row = JTable::getInstance('extension');
-		}
+		$row =& JTable::getInstance('plugin');
 		$row->load($uid);
 		$row->move($inc, 'folder='.$this->database->Quote($row->folder).' AND ordering > -10000 AND ordering < 10000 AND ('.$where.')');
 
@@ -670,7 +625,7 @@ class ResourcesControllerPlugins extends Hubzero_Controller
 	 */
 	public function accesspublicTask()
 	{
-		return $this->accessTask(1);
+		return $this->accessTask(0);
 	}
 	
 	/**
@@ -680,7 +635,7 @@ class ResourcesControllerPlugins extends Hubzero_Controller
 	 */
 	public function accessregisteredTask()
 	{
-		return $this->accessTask(2);
+		return $this->accessTask(1);
 	}
 	
 	/**
@@ -690,7 +645,7 @@ class ResourcesControllerPlugins extends Hubzero_Controller
 	 */
 	public function accessspecialTask()
 	{
-		return $this->accessTask(3);
+		return $this->accessTask(2);
 	}
 
 	/**
@@ -702,21 +657,14 @@ class ResourcesControllerPlugins extends Hubzero_Controller
 	public function accessTask($access=0)
 	{
 		// Check for request forgeries
-		JRequest::checkToken() or JRequest::checkToken('get') or jexit('Invalid Token');
+		JRequest::checkToken() or jexit('Invalid Token');
 
 		// Incoming
 		$cid = JRequest::getVar('id', array(0), 'post', 'array');
 		JArrayHelper::toInteger($cid, array(0));
 
 		// Load the object
-		if (version_compare(JVERSION, '1.6', 'lt')) 
-		{
-			$row = JTable::getInstance('plugin');
-		}
-		else
-		{
-			$row = JTable::getInstance('extension');
-		}
+		$row =& JTable::getInstance('plugin');
 		$row->load($cid[0]);
 
 		// Set the access
@@ -758,23 +706,16 @@ class ResourcesControllerPlugins extends Hubzero_Controller
 	public function saveorderTask()
 	{
 		// Check for request forgeries
-		JRequest::checkToken() or JRequest::checkToken('get') or jexit('Invalid Token');
+		JRequest::checkToken() or jexit('Invalid Token');
 
-		$cid = JRequest::getVar('id', array(0), 'post', 'array');
+		$cid = JRequest::getVar('cid', array(0), 'post', 'array');
 		JArrayHelper::toInteger($cid, array(0));
 
 		$total = count($cid);
 		$order = JRequest::getVar('order', array(0), 'post', 'array');
 		JArrayHelper::toInteger($order, array(0));
 
-		if (version_compare(JVERSION, '1.6', 'lt')) 
-		{
-			$row = JTable::getInstance('plugin');
-		}
-		else
-		{
-			$row = JTable::getInstance('extension');
-		}
+		$row =& JTable::getInstance('plugin');
 		$conditions = array();
 
 		// update ordering values
