@@ -436,7 +436,7 @@ class ToolVersion extends  JTable
 		}
 		if ($toolname or $vid) 
 		{
-			$query = "UPDATE #__tool_version SET unpublished='".JFactory::getDate()->toSql()."' WHERE ";
+			$query = "UPDATE #__tool_version SET unpublished='".date('Y-m-d H:i:s')."' WHERE ";
 			if ($toolname) 
 			{
 				$query .= "toolname=" . $this->_db->Quote($toolname) . " ";
@@ -469,14 +469,14 @@ class ToolVersion extends  JTable
 	 */
 	public function unpublish($toolid=NULL, $vid=0)
 	{
-		$xlog =  Hubzero_Factory::getLogger();
+		$xlog = &Hubzero_Factory::getLogger();
 
 		if (!$toolid) 
 		{
 			return false;
 		}
 
-		$query = "UPDATE #__tool_version SET state='0', unpublished='".JFactory::getDate()->toSql()."' WHERE ";
+		$query = "UPDATE #__tool_version SET state='0', unpublished='".date('Y-m-d H:i:s')."' WHERE ";
 		if (intval($vid)) 
 		{
 			$query.= "id=" . $this->_db->Quote($vid) . " AND ";
@@ -510,7 +510,7 @@ class ToolVersion extends  JTable
 	public function save($toolid=NULL, $version='dev', $create_new = 0)
 	{
 		die('1');
-		$xlog =  Hubzero_Factory::getLogger();
+		$xlog = &Hubzero_Factory::getLogger();
 
 		if (!$this->toolid) 
 		{
@@ -562,11 +562,11 @@ class ToolVersion extends  JTable
 	 * 
 	 * @return     unknown Return description (if any) ...
 	 */
-	public function store($updateNulls = false)
+	public function store()
 	{
 		if (empty($this->id))
 		{
-			$xlog =  Hubzero_Factory::getLogger();
+			$xlog = &Hubzero_Factory::getLogger();
 			$query = "SELECT id FROM #__tool_version WHERE toolname=" . $this->_db->Quote($this->toolname) .
 					" AND instance=" . $this->_db->Quote($this->instance) . ";";
 			$this->_db->setQuery($query);
@@ -597,7 +597,7 @@ class ToolVersion extends  JTable
 	public function getToolVersions($toolid, &$versions, $toolname='', $exclude_dev = 0)
 	{
 		ximport('Hubzero_Tool');
-		$xlog = Hubzero_Factory::getLogger();
+		$xlog =& Hubzero_Factory::getLogger();
 
 		$objA = new ToolAuthor($this->_db);
 
@@ -653,10 +653,10 @@ class ToolVersion extends  JTable
 	 */
 	public function getVersionInfo($id, $version='', $toolname='', $instance='')
 	{
-		$xlog = Hubzero_Factory::getLogger();
+		$xlog =& Hubzero_Factory::getLogger();
 
 		// data comes from mysql
-		$juser  = JFactory::getUser();
+		$juser  =& JFactory::getUser();
 		$query  = "SELECT v.*, d.* ";
 		$query .= "FROM #__tool_version as v LEFT JOIN #__doi_mapping as d ON d.alias = v.toolname AND d.local_revision=v.revision ";
 		if ($id) 
@@ -826,7 +826,7 @@ class ToolVersion extends  JTable
 	 */
 	public function validToolReg(&$tool, &$err, $id, $config, $checker=0, $result=1)
 	{
-	    $xlog = Hubzero_Factory::getLogger();
+	    $xlog =& Hubzero_Factory::getLogger();
 
 		$tgObj = new ToolGroup($this->_db);
 
@@ -1024,7 +1024,7 @@ class ToolVersion extends  JTable
 	 */
 	public function getToolname($instance) 
 	{
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 		$query  = "SELECT toolname FROM #__tool_version WHERE instance=" . $this->_db->Quote($instance) . " LIMIT 1";
 		$this->_db->setQuery($query);
 		$toolname = $this->_db->loadResult();
@@ -1046,7 +1046,7 @@ class ToolVersion extends  JTable
 	 */
 	public function getCurrentVersionProperty($toolname, $property) 
 	{
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 		$query  = "SELECT " . $property . " FROM #__tool_version  WHERE toolname=" . $this->_db->Quote($toolname) . " AND state=1 ORDER BY revision DESC LIMIT 1";
 		$this->_db->setQuery($query);
 		return $this->_db->loadResult();
@@ -1063,7 +1063,7 @@ class ToolVersion extends  JTable
 	 */
 	public function getDevVersionProperty($toolname, $property) 
 	{
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 		$query  = "SELECT " . $property . " FROM #__tool_version WHERE toolname=" . $this->_db->Quote($toolname) . " AND state=3 ORDER BY revision DESC LIMIT 1";
 		$this->_db->setQuery($query);
 		return $this->_db->loadResult();
