@@ -6,19 +6,6 @@ $resp = $this->resp;
 	<h2>Results: <?= $this->title ?></h2>
 </div>
 
-<? if($course = $this->dep->getCourseInfo()) : ?>
-	<div id="content-header-extra">
-		<ul>
-			<li>
-				<? $base = 'index.php?option=com_courses&controller=offering&gid=' . $course->get('alias') . '&offering=' . $course->offering()->get('alias'); ?>
-				<a class="back btn" href="<?php echo JRoute::_($base); ?>">
-					<?php echo JText::_('Back to course'); ?>
-				</a>
-			</li>
-		</ul>
-	</div>
-<? endif; ?>
-
 <div class="main section">
 	<p>Completed <?= date('r', strtotime($resp->getEndTime())); ?></p>
 	<? if ($this->dep->getResultsClosed() == 'details'): ?>
