@@ -271,13 +271,12 @@ function query_gen(&$dd)
 		}
 	}
 
-
 	$where_str = '';
 	$having_str = '';
 
 	if (count($where_filter) > 0) {
 		$where_filter_arr = array();
-		foreach ($where_filter as $key=>$val) {
+		foreach ($where_filter as $key => $val) {
 			if ($val['fieldtype'] == 'number' || $val['fieldtype'] == 'datetime') {
 				$val['val'] = strtolower($val['val']);
 				if (strstr($val['val'], 'to')) {
@@ -297,12 +296,12 @@ function query_gen(&$dd)
 						$val['val'] = str_replace('<', "< '", $val['val']);
 					}
 					$where_filter_arr[] = $val['col'] . " " . $val['val'] . "'";
-				} elseif (strstr($val['val'], '=')) {
-					$val['val'] = trim(str_replace('=', '', $val['val']));
-					$where_filter_arr[] = $val['col'] . " = '" . $val['val'] . "'";
 				} elseif (strstr($val['val'], '!=')) {
 					$val['val'] = trim(str_replace('!=', '', $val['val']));
 					$where_filter_arr[] = "NOT " . $val['col'] . " <=> '" . $val['val'] . "'";
+				} elseif (strstr($val['val'], '=')) {
+					$val['val'] = trim(str_replace('=', '', $val['val']));
+					$where_filter_arr[] = $val['col'] . " = '" . $val['val'] . "'";
 				} elseif (strstr($val['val'], '!')) {
 					$val['val'] = trim(str_replace('!', '', $val['val']));
 					$where_filter_arr[] = $val['col'] . " NOT LIKE '%" . $val['val'] . "%'";
@@ -329,12 +328,12 @@ function query_gen(&$dd)
 					$where_filter_arr[] = $max_col . " " . $val['val'];
 				} elseif (strstr($val['val'], '>')) {
 					$where_filter_arr[] = $min_col . " " . $val['val'];
-				} elseif (strstr($val['val'], '=')) {
-					$val['val'] = trim(str_replace('=', '', $val['val']));
-					$where_filter_arr[] = $val['col'] . " = '" . $val['val'] . "'";
 				} elseif (strstr($val['val'], '!=')) {
 					$val['val'] = trim(str_replace('!=', '', $val['val']));
 					$where_filter_arr[] = "NOT " . $val['col'] . " <=> '" . $val['val'] . "'";
+				} elseif (strstr($val['val'], '=')) {
+					$val['val'] = trim(str_replace('=', '', $val['val']));
+					$where_filter_arr[] = $val['col'] . " = '" . $val['val'] . "'";
 				} elseif (strstr($val['val'], '!')) {
 					$val['val'] = trim(str_replace('!', '', $val['val']));
 					$where_filter_arr[] = $val['col'] . " NOT LIKE '%" . $val['val'] . "%'";
@@ -343,12 +342,12 @@ function query_gen(&$dd)
 				}
 			} elseif (isset($val['filtered_view'])) {
 				$where_filter_arr[] = $val['col'] . " = '" . $val['val'] . "'";
-			} elseif (strpos($val['val'], '=') === 0) {
-				$val['val'] = trim(str_replace('=', '', $val['val']));
-				$where_filter_arr[] = $val['col'] . " = '" . $val['val'] . "'";
 			} elseif (strpos($val['val'], '!=') === 0) {
 				$val['val'] = trim(str_replace('!=', '', $val['val']));
 				$where_filter_arr[] = "NOT " . $val['col'] . " <=> '" . $val['val'] . "'";
+			} elseif (strpos($val['val'], '=') === 0) {
+				$val['val'] = trim(str_replace('=', '', $val['val']));
+				$where_filter_arr[] = $val['col'] . " = '" . $val['val'] . "'";
 			} elseif (strpos($val['val'], '!') === 0) {
 				$val['val'] = trim(str_replace('!', '', $val['val']));
 				$where_filter_arr[] = $val['col'] . " NOT LIKE '%" . $val['val'] . "%'";
@@ -388,12 +387,12 @@ function query_gen(&$dd)
 						$val['val'] = str_replace('<', "< '", $val['val']);
 					}
 					$having_filter_arr[] = $val['col'] . " " . $val['val'] . "'";
-				} elseif (strstr($val['val'], '=')) {
-					$val['val'] = trim(str_replace('=', '', $val['val']));
-					$having_filter_arr[] = $val['col'] . " = '" . $val['val'] . "'";
 				} elseif (strstr($val['val'], '!=')) {
 					$val['val'] = trim(str_replace('!=', '', $val['val']));
 					$having_filter_arr[] = "NOT " . $val['col'] . " <=> '" . $val['val'] . "'";
+				} elseif (strstr($val['val'], '=')) {
+					$val['val'] = trim(str_replace('=', '', $val['val']));
+					$having_filter_arr[] = $val['col'] . " = '" . $val['val'] . "'";
 				} elseif (strstr($val['val'], '!')) {
 					$val['val'] = trim(str_replace('!', '', $val['val']));
 					$having_filter_arr[] = $val['col'] . " NOT LIKE '%" . $val['val'] . "%'";
@@ -418,12 +417,12 @@ function query_gen(&$dd)
 					$having_filter_arr[] = $max_col . " " . $val['val'];
 				} elseif (strstr($val['val'], '>')) {
 					$having_filter_arr[] = $min_col . " " . $val['val'];
-				} elseif (strstr($val['val'], '=')) {
-					$val['val'] = trim(str_replace('=', '', $val['val']));
-					$having_filter_arr[] = $val['col'] . " = '" . $val['val'] . "'";
 				} elseif (strstr($val['val'], '!=')) {
 					$val['val'] = trim(str_replace('!=', '', $val['val']));
 					$having_filter_arr[] = "NOT " . $val['col'] . " <=> '" . $val['val'] . "'";
+				} elseif (strstr($val['val'], '=')) {
+					$val['val'] = trim(str_replace('=', '', $val['val']));
+					$having_filter_arr[] = $val['col'] . " = '" . $val['val'] . "'";
 				} elseif (strstr($val['val'], '!')) {
 					$val['val'] = trim(str_replace('!', '', $val['val']));
 					$having_filter_arr[] = $val['col'] . " NOT LIKE '%" . $val['val'] . "%'";
@@ -560,7 +559,7 @@ function query_gen(&$dd)
 
 	$order = array();
 
-	$sorting = JRequest::getString('iSortCol_0', false);
+	$sorting = JRequest::getVar('iSortCol_0', false);
 	if ($sorting !== false && count($cols_vis) > 0) {
 		$sort_col_count = JRequest::getInt('iSortingCols', 0);
 		for ($i = 0 ; $i < $sort_col_count; $i++) {
@@ -592,12 +591,12 @@ function query_gen(&$dd)
 
 	// Limit
 	$limit = '';
-	$no_limit = JRequest::getString('nolimit', false);
-	$limit_start = JRequest::getInt('iDisplayStart', false);
-	$limit_length = JRequest::getInt('iDisplayLength', $dv_conf['settings']['limit']);
-	if ($no_limit === false && $limit_start !== false && $limit_length !== -1) {
+	$no_limit = JRequest::getVar('nolimit', false);
+	$limit_start = JRequest::getVar('iDisplayStart', false);
+	$limit_length = JRequest::getVar('iDisplayLength', $dv_conf['settings']['limit']);
+	if ($no_limit === false && $limit_start !== false && $limit_length != '-1') {
 		$limit = " LIMIT $limit_start, $limit_length";
-	} elseif (!$no_limit && isset($dd['serverside']) && $dd['serverside']) {
+	} elseif ($no_limit === false && isset($dd['serverside']) && $dd['serverside']) {
 		$limit = " LIMIT 0, " . $dv_conf['settings']['limit'];
 	}
 
@@ -612,8 +611,12 @@ function query_gen_total($dd) {
 		$col = 'DISTINCT ' . $dd['group_by'];
 	}
 
-	$sql = "SELECT COUNT($col) AS `total` FROM `";
-	$sql .= $dd['table'] . '` ';
+	if (substr($dd['table'], 0, 1) == '(') {
+		$sql = "SELECT COUNT($col) AS `total` FROM " . $dd['table'] . ' ';
+	} else {
+		$sql = "SELECT COUNT($col) AS `total` FROM `";
+		$sql .= $dd['table'] . '` ';
+	}
 
 	if (isset($dd['joins'])) {
 		foreach ($dd['joins'] as $j) {
@@ -621,6 +624,23 @@ function query_gen_total($dd) {
 		}
 	}
 
+	if (isset($dd['join'])) {
+		foreach ($dd['join'] as $j) {
+			$type = isset($j['type'])? $j['type']: 'LEFT JOIN';
+			$con = array();
+			foreach ($j['fields'] as $f1=>$f2) {
+				if ($f1 == 'raw') {
+					$con[] = $f2;
+				} else {
+					$con[] = "$f1=$f2";
+				}
+			}
+			$con = implode(' AND ', $con);
+			$sql .= "$type " . $j['table'] . ' ON (' . $con .  ') ';
+		}
+	}
+
+
 	$where_str = '';
 
 	if (isset($dd['where'])) {
@@ -638,6 +658,14 @@ function query_gen_total($dd) {
 
 	$sql .= $where_str;
 
+	$group_by = '';
+
+	if (isset($dd['group_by'])) {
+		$group_by .= ' GROUP BY ' . $dd['group_by'] . '';
+	}
+
+	$sql .= $group_by;
+
 	$having_str = '';
 	if (isset($dd['having'])) {
 		$having_str = ' HAVING ';
