@@ -48,7 +48,7 @@ class ContribtoolHtml
 	 * @param      string $tag Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public static function error( $msg, $tag='p' )
+	public function error( $msg, $tag='p' )
 	{
 		return '<'.$tag.' class="error">'.$msg.'</'.$tag.'>'."\n";
 	}
@@ -62,7 +62,7 @@ class ContribtoolHtml
 	 * @param      string $tag Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public static function warning( $msg, $tag='p' )
+	public function warning( $msg, $tag='p' )
 	{
 		return '<'.$tag.' class="warning">'.$msg.'</'.$tag.'>'."\n";
 	}
@@ -76,7 +76,7 @@ class ContribtoolHtml
 	 * @param      string $tag Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public static function passed( $msg, $tag='p' )
+	public function passed( $msg, $tag='p' )
 	{
 		return '<'.$tag.' class="passed">'.$msg.'</'.$tag.'>'."\n";
 	}
@@ -89,7 +89,7 @@ class ContribtoolHtml
 	 * @param      string $msg Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public static function alert( $msg )
+	public function alert( $msg )
 	{
 		return "<script type=\"text/javascript\"> alert('".$msg."'); window.history.go(-1); </script>\n";
 	}
@@ -103,7 +103,7 @@ class ContribtoolHtml
 	 * @param      string $txt Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public static function hed($level, $txt)
+	public function hed($level, $txt)
 	{
 		return '<h'.$level.'>'.$txt.'</h'.$level.'>';
 	}
@@ -118,7 +118,7 @@ class ContribtoolHtml
 	 * @param      string $id Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public static function div($txt, $cls='', $id='')
+	public function div($txt, $cls='', $id='')
 	{
 		$html  = '<div';
 		$html .= ($cls) ? ' class="'.$cls.'"' : '';
@@ -144,7 +144,7 @@ class ContribtoolHtml
 	 * @param      unknown $stime Parameter description (if any) ...
 	 * @return     unknown Return description (if any) ...
 	 */
-	public static function mkt($stime)
+	public function mkt($stime)
 	{
 		if ($stime && preg_match("/([0-9]{4})-([0-9]{2})-([0-9]{2})[ ]([0-9]{2}):([0-9]{2}):([0-9]{2})/", $stime, $regs )) 
 		{
@@ -161,7 +161,7 @@ class ContribtoolHtml
 	 * @param      number $timestamp Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public static function timeAgoo($timestamp)
+	public function timeAgoo($timestamp)
 	{
 		// Store the current time
 		$current_time = time();
@@ -245,7 +245,7 @@ class ContribtoolHtml
 	 * @param      unknown $timestamp Parameter description (if any) ...
 	 * @return     unknown Return description (if any) ...
 	 */
-	public static function timeAgo($timestamp)
+	public function timeAgo($timestamp)
 	{
 		$timestamp = ContribtoolHtml::mkt($timestamp);
 		$text = ContribtoolHtml::timeAgoo($timestamp);
@@ -270,7 +270,7 @@ class ContribtoolHtml
 	 * @param      string $jscall Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public static function formSelect($name, $idname, $array, $value, $class='', $jscall='')
+	public function formSelect($name, $idname, $array, $value, $class='', $jscall='')
 	{
 		$out  = '<select name="'.$name.'" id="'.$idname.'"';
 		$out .= ($class)  ? ' class="'.$class.'"'           : ''."";
@@ -299,7 +299,7 @@ class ContribtoolHtml
 	 * @param      string $action Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public static function primaryButton($class, $href, $msg, $xtra='', $title='', $action='')
+	public function primaryButton($class, $href, $msg, $xtra='', $title='', $action='')
 	{
 		//$title = str_replace('"', '&quot;', $title);
 		$html  = '<span id="test-document"><a class="'.$class.'" style="padding:0.1em 1em 0 1em;"  href="'.$href.'" title="'.htmlentities($title).'" '.$action.'>'.$msg.'</a>';
@@ -317,10 +317,10 @@ class ContribtoolHtml
 	 * @param      string $toolnum Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public static function getNumofTools($status, $toolnum='')
+	public function getNumofTools($status, $toolnum='')
 	{
 		// get hub parameters
-		$jconfig = JFactory::getConfig();
+		$jconfig =& JFactory::getConfig();
 		$live_site = rtrim(JURI::base(),'/');
 		$sitename = $jconfig->getValue('config.sitename');
 		
@@ -346,7 +346,7 @@ class ContribtoolHtml
 	 * @param      integer $stateNum Parameter description (if any) ...
 	 * @return     boolean Return description (if any) ...
 	 */
-	public static function toolActive($stateNum) 
+	public function toolActive($stateNum) 
 	{
 		if ($stateNum == 8 || $stateNum == 9) 
 		{
@@ -363,7 +363,7 @@ class ContribtoolHtml
 	 * @param      integer $stateNum Parameter description (if any) ...
 	 * @return     boolean Return description (if any) ...
 	 */
-	public static function toolWIP($stateNum) 
+	public function toolWIP($stateNum) 
 	{
 		if ($stateNum == 2 || $stateNum == 9 || $stateNum == 1) 
 		{
@@ -380,7 +380,7 @@ class ContribtoolHtml
 	 * @param      integer $stateNum Parameter description (if any) ...
 	 * @return     boolean Return description (if any) ...
 	 */
-	public static function toolEstablished($stateNum) 
+	public function toolEstablished($stateNum) 
 	{
 		if ($stateNum == 1 || $stateNum == 9) 
 		{
@@ -398,7 +398,7 @@ class ContribtoolHtml
 	 * @param      string &$statusClass Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public static function getStatusClass($statusNum, &$statusClass) 
+	public function getStatusClass($statusNum, &$statusClass) 
 	{
 		switch ($statusNum)
 		{
@@ -420,7 +420,7 @@ class ContribtoolHtml
 	 * @param      unknown &$statusName Parameter description (if any) ...
 	 * @return     integer Return description (if any) ...
 	 */
-	public static function getStatusName($statusNum, &$statusName) 
+	public function getStatusName($statusNum, &$statusName) 
 	{
 		switch ($statusNum)
 		{
@@ -447,7 +447,7 @@ class ContribtoolHtml
 	 * @param      integer $statusNum Parameter description (if any) ...
 	 * @return     integer Return description (if any) ...
 	 */
-	public static function getStatusNum($statusName, $statusNum=1)
+	public function getStatusNum($statusName, $statusNum=1)
 	{
 		switch (strtolower($statusName))
 		{
@@ -473,7 +473,7 @@ class ContribtoolHtml
 	 * @param      string $priority Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public static function getPriority($int, $priority='')
+	public function getPriority($int, $priority='')
 	{
 		switch ($int)
 		{
@@ -497,14 +497,14 @@ class ContribtoolHtml
 	 * @param      string $team Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public static function getDevTeam($members, $obj = 1, $team='') 
+	public function getDevTeam($members, $obj = 1, $team='') 
 	{
 		if ($members && count($members) > 0) 
 		{
 			foreach ($members as $member) 
 			{
 				$uid = ($obj) ? $member->uidNumber : $member;
-				$juser = JUser::getInstance($uid);
+				$juser =& JUser::getInstance($uid);
 				if (is_object($juser)) 
 				{
 					$login = $juser->get('username');
@@ -533,7 +533,7 @@ class ContribtoolHtml
 	 * @param      string $list Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public static function getGroups($groups, $obj = 1, $list='') 
+	public function getGroups($groups, $obj = 1, $list='') 
 	{
 		if ($groups && count($groups) > 0) 
 		{
@@ -556,7 +556,7 @@ class ContribtoolHtml
 	 * @param      string $toolaccess Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public static function getToolAccess($access, $groups, $toolaccess='')
+	public function getToolAccess($access, $groups, $toolaccess='')
 	{
 		switch ($access)
 		{
@@ -593,7 +593,7 @@ class ContribtoolHtml
 	 * @param      string $codeaccess Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public static function getCodeAccess($access, $codeaccess = '')
+	public function getCodeAccess($access, $codeaccess = '')
 	{
 		switch ($access)
 		{
@@ -614,7 +614,7 @@ class ContribtoolHtml
 	 * @param      string $wikiaccess Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public static function getWikiAccess($access, $wikiaccess = '')
+	public function getWikiAccess($access, $wikiaccess = '')
 	{
 		switch ($access)
 		{
@@ -634,7 +634,7 @@ class ContribtoolHtml
 	 * @param      unknown $active_stage Parameter description (if any) ...
 	 * @return     void
 	 */
-	public static function writeApproval($active_stage)
+	public function writeApproval($active_stage)
 	{
 		//$stages = array(JText::_('COM_TOOLS_CONTRIBTOOL_STEP_CONFIRM_VERSION'),JText::_('COM_TOOLS_CONTRIBTOOL_STEP_CONFIRM_LICENSE'), JText::_('COM_TOOLS_CONTRIBTOOL_STEP_APPEND_NOTES'), JText::_('COM_TOOLS_CONTRIBTOOL_STEP_CONFIRM_APPROVE'));
 		$stages = array(JText::_('COM_TOOLS_CONTRIBTOOL_STEP_CONFIRM_VERSION'),JText::_('COM_TOOLS_CONTRIBTOOL_STEP_CONFIRM_LICENSE'), JText::_('COM_TOOLS_CONTRIBTOOL_STEP_CONFIRM_APPROVE'));
@@ -675,7 +675,7 @@ class ContribtoolHtml
 	 * @param      unknown $value Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public static function selectAccess($as, $value)
+	public function selectAccess($as, $value)
 	{
 		$html  = '<select name="access">';
 		for ($i=0, $n=count( $as ); $i < $n; $i++)
@@ -703,7 +703,7 @@ class ContribtoolHtml
 	 * @param      unknown $value Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public static function selectGroup($groups, $value)
+	public function selectGroup($groups, $value)
 	{
 		$html  = '<select name="group_owner">'."\n";
 		$html .= '<option value="">'.JText::_('COM_TOOLS_SELECT_GROUP').'</option>'."\n";
@@ -732,7 +732,7 @@ class ContribtoolHtml
 	 * @param      integer $addnew Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public static function writeNotesArea($notes, $option, $type='', $edititem = 0, $addnew = 1)
+	public function writeNotesArea($notes, $option, $type='', $edititem = 0, $addnew = 1)
 	{
 
 		$out ='';
@@ -769,7 +769,7 @@ class ContribtoolHtml
 	 * @param      string $type Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public static function addNoteArea($i, $option, $type = 'item')
+	public function addNoteArea($i, $option, $type = 'item')
 	{
 		$out  = '';
 	 	$out .= '<label>'."\n";
@@ -791,7 +791,7 @@ class ContribtoolHtml
 	 * @param      string $tag Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public static function parseTag($text, $tag)
+	public function parseTag($text, $tag)
 	{
 		preg_match("#<nb:".$tag.">(.*?)</nb:".$tag.">#s", $text, $matches);
 		if (count($matches) > 0) {
@@ -812,7 +812,7 @@ class ContribtoolHtml
 	 * @param      unknown $pee Parameter description (if any) ...
 	 * @return     unknown Return description (if any) ...
 	 */
-	public static function txt_unpee($pee)
+	public function txt_unpee($pee)
 	{
 		$pee = str_replace("\t", '', $pee);
 		$pee = str_replace('</p><p>', '', $pee);
@@ -831,7 +831,7 @@ class ContribtoolHtml
 	 * @param      integer $someid Parameter description (if any) ...
 	 * @return     integer Return description (if any) ...
 	 */
-	public static function niceidformat($someid)
+	public function niceidformat($someid)
 	{
 		while (strlen($someid) < 5)
 		{
@@ -849,7 +849,7 @@ class ContribtoolHtml
 	 * @param      string $base_path Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public static function getFileAttribs( $path, $base_path='' )
+	public function getFileAttribs( $path, $base_path='' )
 	{
 		// Return nothing if no path provided
 		if (!$path) {
@@ -919,7 +919,7 @@ class ContribtoolHtml
 	 * @param      mixed $file_size Parameter description (if any) ...
 	 * @return     mixed Return description (if any) ...
 	 */
-	public static function formatsize($file_size)
+	public function formatsize($file_size)
 	{
 		if ($file_size >= 1073741824) {
 			$file_size = round($file_size / 1073741824 * 100) / 100 . ' <abbr title="gigabytes">Gb</abbr>';
