@@ -117,7 +117,7 @@ class plgCoursesProgress extends JPlugin
 			return $arr;
 		}
 
-		$this->member = $course->offering()->section()->member(JFactory::getUser()->get('id'));
+		$this->juser  = JFactory::getUser();
 		$this->course = $course;
 		$this->base   = 'index.php?option=com_courses&gid=' . $this->course->get('alias') . '&offering=' . $this->course->offering()->get('alias');
 		$this->base  .= ($this->course->offering()->section()->get('alias') != '__default' ? ':' . $this->course->offering()->section()->get('alias') : '');
@@ -132,18 +132,15 @@ class plgCoursesProgress extends JPlugin
 			)
 		);
 		$this->view->course  = $course;
-		$this->view->member  = $this->member;
+		$this->view->juser   = $this->juser;
 		$this->view->option  = 'com_courses';
-		$this->view->base    = $this->base;
 
 		switch (JRequest::getWord('action'))
 		{
-			case 'getprogressrows':     $this->getprogressrows();     break;
-			case 'getprogressdata':     $this->getprogressdata();     break;
-			case 'getgradebookdata':    $this->getgradebookdata();    break;
+			case 'showgradebook':       $this->showgradebook();       break;
+			case 'getData':             $this->getData();             break;
 			case 'exportcsv':           $this->exportcsv();           break;
 			case 'savegradebookitem':   $this->savegradebookitem();   break;
-			case 'deletegradebookitem': $this->deletegradebookitem(); break;
 			case 'savegradebookentry':  $this->savegradebookentry();  break;
 			case 'resetgradebookentry': $this->resetgradebookentry(); break;
 			case 'policysave':          $this->policysave();          break;
@@ -172,125 +169,57 @@ class plgCoursesProgress extends JPlugin
 			if($student_id = JRequest::getInt('id', false))
 			{
 				$layout = 'student';
-				$this->view->member = $this->course->offering()->section()->member($student_id);
+				$this->view->juser  = JFactory::getUser($student_id);
 			}
 		}
 
 		// Add some styles to the view
-		Hubzero_Document::addPluginStylesheet('courses', 'progress', $layout.'.css');
+		Hubzero_Document::addPluginStylesheet('courses', 'progress');
 		Hubzero_Document::addPluginScript('courses', 'progress', $layout.'progress');
-		Hubzero_Document::addSystemScript('handlebars');
 
 		// Set the layout
 		$this->view->setLayout($layout);
 	}
 
 	/**
-	 * Get progress data
+	 * Display gradebook
 	 *
 	 * @return void
 	 **/
-	private function getprogressrows()
+	private function showgradebook()
 	{
 		// Only allow for instructors
 		if (!$this->course->offering()->section()->access('manage'))
 		{
-			echo json_encode(array('success'=>false));
-			exit();
-		}
-
-		// Get our limit and limitstart
-		$limit = JRequest::getInt('limit', '10');
-		$start = JRequest::getInt('limitstart', 0);
-
-		// Get all section members
-		$members    = $this->course->offering()->section()->members(array('student'=>1, 'limit'=>$limit, 'start'=>$start));
-		$member_ids = array();
-		$mems       = array();
-
-		foreach ($members as $m)
-		{
-			$member_ids[] = $m->get('id');
-			$mems[] = array(
-				'id'        => $m->get('id'),
-				'user_id'   => $m->get('user_id'),
-				'name'      => JFactory::getUser($m->get('user_id'))->get('name'),
-				'thumb'     => ltrim(Hubzero_User_Profile_Helper::getMemberPhoto($m->get('user_id'), 0, true), DS),
-				'full'      => ltrim(Hubzero_User_Profile_Helper::getMemberPhoto($m->get('user_id'), 0, false), DS),
-				'enrolled'  => (($m->get('enrolled') != '0000-00-00 00:00:00')
-									? JFactory::getDate(strtotime($m->get('enrolled')))->format('M j, Y')
-									: 'unknown'),
-				'lastvisit' => ((JFactory::getUser($m->get('user_id'))->get('lastvisitDate') != '0000-00-00 00:00:00')
-									? JFactory::getDate(strtotime(JFactory::getUser($m->get('user_id'))->get('lastvisitDate')))->format('M j, Y')
-									: 'never')
+			// Redirect with message
+			JFactory::getApplication()->redirect(
+				JRoute::_($this->base, false),
+				'You don\'t have permission to do this!',
+				'warning'
 			);
+			return;
 		}
 
-		// Refresh the grades
-		$this->course->offering()->gradebook()->refresh($member_ids);
-
-		// Get the grades
-		$grades    = $this->course->offering()->gradebook()->grades(array('unit', 'course'));
-		$progress  = $this->course->offering()->gradebook()->progress($member_ids);
-		$passing   = $this->course->offering()->gradebook()->passing($member_ids);
-
-		echo json_encode(
-			array(
-				'members'     => $mems,
-				'grades'      => $grades,
-				'progress'    => $progress,
-				'passing'     => $passing
-			)
-		);
-
-		exit();
-	}
-
-	/**
-	 * Get grading policy
-	 *
-	 * @return void
-	 **/
-	private function getprogressdata()
-	{
-		// Only allow for instructors
-		if (!$this->course->offering()->section()->access('manage'))
+		// Now, also make sure either section managers can edit, or user is a course manager
+		if (!$this->course->config()->get('section_grade_policy', true) && !$this->course->offering()->access('manage'))
 		{
-			echo json_encode(array('success'=>false));
-			exit();
+			// Redirect with message
+			JFactory::getApplication()->redirect(
+				JRoute::_($this->base . '&active=progress', false),
+				'You don\'t have permission to do this!',
+				'warning'
+			);
+			return;
 		}
 
-		// Get the grading policy
-		$gradePolicy = new CoursesModelGradePolicies($this->course->offering()->section()->get('grade_policy_id'));
-		$policy = new stdClass();
-		$policy->description     = $gradePolicy->get('description');
-		$policy->exam_weight     = $gradePolicy->get('exam_weight') * 100;
-		$policy->quiz_weight     = $gradePolicy->get('quiz_weight') * 100;
-		$policy->homework_weight = $gradePolicy->get('homework_weight') * 100;
-		$policy->threshold       = $gradePolicy->get('threshold') * 100;
-		$policy->editable        = ($this->course->config()->get('section_grade_policy', true) || $this->course->offering()->access('manage')) ? true : false;
+		// Add some styles to the view
+		Hubzero_Document::addPluginStylesheet('courses', 'progress', 'gradebook.css');
+		Hubzero_Document::addPluginScript('courses', 'progress', 'gradebook');
+		Hubzero_Document::addSystemScript('handlebars');
+		//Hubzero_Document::addSystemScript('jquery.fancyselect.min');
+		//Hubzero_Document::addSystemStylesheet('jquery.fancyselect.css');
 
-		// Get our units
-		$unitsObj = $this->course->offering()->units();
-		$units    = array();
-		foreach ($unitsObj as $u)
-		{
-			$units[] = array('id'=>$u->get('id'), 'title'=>$u->get('title'));
-		}
-
-		// Get total number of members
-		$members_cnt = $this->course->offering()->section()->members(array('student'=>1, 'count'=>true));
-
-		echo json_encode(
-			array(
-				'gradepolicy' => $policy,
-				'units'       => $units,
-				'members_cnt' => $members_cnt,
-				'course_id'   => $this->course->get('id')
-			)
-		);
-
-		exit();
+		$this->view->setLayout('gradebook');
 	}
 
 	/**
@@ -298,7 +227,7 @@ class plgCoursesProgress extends JPlugin
 	 *
 	 * @return void
 	 **/
-	private function getgradebookdata()
+	private function getData()
 	{
 		// Only allow for instructors
 		if (!$this->course->offering()->section()->access('manage'))
@@ -307,18 +236,24 @@ class plgCoursesProgress extends JPlugin
 			exit();
 		}
 
+		// Now, also make sure either section managers can edit, or user is a course manager
+		if (!$this->course->config()->get('section_grade_policy', true) && !$this->course->offering()->access('manage'))
+		{
+			echo json_encode(array('success'=>false));
+			exit();
+		}
+
 		// Get all section members
 		$members = $this->course->offering()->section()->members(array('student'=>1));
 		$mems    = array();
 
 		foreach ($members as $m)
 		{
-			$mems[] = array('id'=>$m->get('id'), 'name'=>JFactory::getUser($m->get('user_id'))->get('name'));
+			$mems[] = array('id'=>$m->get('user_id'), 'name'=>JFactory::getUser($m->get('user_id'))->get('name'));
 		}
 
 		// Refresh the grades
-		// @FIXME: commenting this out for the time being...no need to refresh grades on both the progress and gradebook views
-		//$this->course->offering()->gradebook()->refresh();
+		$this->course->offering()->gradebook()->refresh();
 
 		// Get the grades
 		$grades = $this->course->offering()->gradebook()->grades();
@@ -328,25 +263,17 @@ class plgCoursesProgress extends JPlugin
 		$assets = $asset->find(
 			array(
 				'w' => array(
-					'course_id'   => $this->course->get('id'),
-					'section_id'  => $this->course->offering()->section()->get('id'),
-					'offering_id' => $this->course->offering()->get('id'),
-					'asset_type'  => 'form',
-					'state'       => 1
+					'course_id'  => $this->course->get('id'),
+					'section_id' => $this->course->offering()->section()->get('id'),
+					'asset_type' => 'form',
+					'state'      => 1
 				),
 				'order_by'  => 'title',
 				'order_dir' => 'ASC'
 			)
 		);
 
-		echo json_encode(
-			array(
-				'assets'    => $assets,
-				'members'   => $mems,
-				'grades'    => $grades,
-				'canManage' => (($this->course->access('manage')) ? true : false)
-			)
-		);
+		echo json_encode(array('assets'=>$assets, 'members'=>$mems, 'grades'=>$grades));
 		exit();
 	}
 
@@ -364,12 +291,18 @@ class plgCoursesProgress extends JPlugin
 			exit();
 		}
 
+		// Now, also make sure either section managers can edit, or user is a course manager
+		if (!$this->course->config()->get('section_grade_policy', true) && !$this->course->offering()->access('manage'))
+		{
+			echo json_encode(array('success'=>false));
+			exit();
+		}
+
 		// Get all section members
 		$members = $this->course->offering()->section()->members(array('student'=>1));
 
 		// Refresh the grades
-		// @FIXME: This seems to cause memory problems...neeed trigger based solution, rather than one-time computation
-		//$this->course->offering()->gradebook()->refresh();
+		$this->course->offering()->gradebook()->refresh();
 
 		// Get the grades
 		$grades = $this->course->offering()->gradebook()->grades();
@@ -400,7 +333,6 @@ class plgCoursesProgress extends JPlugin
 
 		$row   = array();
 		$row[] = 'Student Name';
-		$row[] = 'Student Email';
 		foreach ($assets as $a)
 		{
 			$row[] = $a->title;
@@ -411,10 +343,9 @@ class plgCoursesProgress extends JPlugin
 		{
 			$row   = array();
 			$row[] = JFactory::getUser($m->get('user_id'))->get('name');
-			$row[] = JFactory::getUser($m->get('user_id'))->get('email');
 			foreach($assets as $a)
 			{
-				$row[] = (isset($grades[$m->get('id')]['assets'][$a->id]['score'])) ? $grades[$m->get('id')]['assets'][$a->id]['score'] : '-';
+				$row[] = $grades[$m->get('user_id')]['assets'][$a->id]['score'];
 			}
 			echo implode(',', $row) . "\n";
 		}
@@ -458,7 +389,7 @@ class plgCoursesProgress extends JPlugin
 			$asset->set('title', 'New Item');
 			$asset->set('type', 'form');
 			$asset->set('subtype', 'exam');
-			$asset->set('created', JFactory::getDate()->toSql());
+			$asset->set('created', date("Y-m-d H:i:s"));
 			$asset->set('created_by', JFactory::getUser()->get('id'));
 			$asset->set('state', 1);
 			$asset->set('course_id', $this->course->get('id'));
@@ -474,51 +405,6 @@ class plgCoursesProgress extends JPlugin
 		exit();
 	}
 
-	/**
-	 * Delete a gradebook item
-	 *
-	 * @return void
-	 **/
-	private function deletegradebookitem()
-	{
-		// Only allow for instructors
-		if (!$this->course->offering()->section()->access('manage'))
-		{
-			echo json_encode(array('success'=>false));
-			exit();
-		}
-
-		// Now, also make sure either section managers can edit, or user is a course manager
-		if (!$this->course->config()->get('section_grade_policy', true) && !$this->course->offering()->access('manage'))
-		{
-			echo json_encode(array('success'=>false));
-			exit();
-		}
-
-		$asset = new CoursesTableAsset(JFactory::getDBO());
-
-		// Get request variables
-		if ($asset_id = JRequest::getInt('asset_id', false))
-		{
-			$asset->load($asset_id);
-			$asset->set('state', 2);
-		}
-		else
-		{
-			echo json_encode(array('success'=>false));
-			exit();
-		}
-
-		if (!$asset->store())
-		{
-			echo json_encode(array('success'=>false));
-			exit();
-		}
-
-		echo json_encode(array('success'=>true));
-		exit();
-	}
-
 	/**
 	 * Save a gradebook entry
 	 *
@@ -533,8 +419,15 @@ class plgCoursesProgress extends JPlugin
 			exit();
 		}
 
+		// Now, also make sure either section managers can edit, or user is a course manager
+		if (!$this->course->config()->get('section_grade_policy', true) && !$this->course->offering()->access('manage'))
+		{
+			echo json_encode(array('success'=>false));
+			exit();
+		}
+
 		// Get request variables
-		if (!$member_id = JRequest::getInt('student_id', false))
+		if (!$user_id = JRequest::getInt('student_id', false))
 		{
 			echo json_encode(array('success'=>false));
 			exit();
@@ -551,11 +444,11 @@ class plgCoursesProgress extends JPlugin
 		}
 
 		$grade = new CoursesTableGradeBook(JFactory::getDBO());
-		$grade->loadByUserAndAssetId($member_id, $asset_id);
+		$grade->loadByUserAndAssetId($user_id, $asset_id);
 
 		if (!$grade->id)
 		{
-			$grade->set('member_id', $member_id);
+			$grade->set('user_id', $user_id);
 			$grade->set('scope', 'asset');
 			$grade->set('scope_id', $asset_id);
 		}
@@ -587,7 +480,7 @@ class plgCoursesProgress extends JPlugin
 		}
 
 		// Get request variables
-		if (!$member_id = JRequest::getInt('student_id', false))
+		if (!$user_id = JRequest::getInt('student_id', false))
 		{
 			echo json_encode(array('success'=>false));
 			exit();
@@ -599,7 +492,7 @@ class plgCoursesProgress extends JPlugin
 		}
 
 		$grade = new CoursesTableGradeBook(JFactory::getDBO());
-		$grade->loadByUserAndAssetId($member_id, $asset_id);
+		$grade->loadByUserAndAssetId($user_id, $asset_id);
 
 		if (!$grade->id)
 		{
@@ -793,32 +686,53 @@ class plgCoursesProgress extends JPlugin
 			}
 		}
 
-		if (JRequest::getInt('no_html', false))
+		// Redirect with message
+		JFactory::getApplication()->redirect(
+			JRoute::_($this->base . '&active=progress', false),
+			'Scoring policy successfully restored to the default configuration!',
+			'passed'
+		);
+		return;
+	}
+
+	/**
+	 * Refresh grades
+	 *
+	 * @return void
+	 **/
+	private function refresh()
+	{
+		// Only allow for instructors
+		if (!$this->course->offering()->section()->access('manage'))
 		{
-			$gp = new CoursesModelGradePolicies(1);
-			$policy->description     = $gp->get('description');
-			$policy->exam_weight     = $gp->get('exam_weight') * 100;
-			$policy->quiz_weight     = $gp->get('quiz_weight') * 100;
-			$policy->homework_weight = $gp->get('homework_weight') * 100;
-			$policy->threshold       = $gp->get('threshold') * 100;
-			echo json_encode(
-				array(
-					'success'     => true,
-					'message'     => 'Scoring policy successfully restored to the default configuration!',
-					'gradepolicy' => $policy
-				)
+			// Redirect with message
+			JFactory::getApplication()->redirect(
+				JRoute::_($this->base, false),
+				'You don\'t have permission to do this!',
+				'warning'
 			);
-			exit();
+			return;
 		}
-		else
+
+		// Get gradebook instance
+		$gradebook = new CoursesModelGradeBook(null);
+		if (!$gradebook->refresh($this->course))
 		{
 			// Redirect with message
 			JFactory::getApplication()->redirect(
 				JRoute::_($this->base . '&active=progress', false),
-				'Scoring policy successfully restored to the default configuration!',
-				'passed'
+				'Something went wrong!',
+				'error'
 			);
 			return;
 		}
+
+		// Redirect with message
+		JFactory::getApplication()->redirect(
+			JRoute::_($this->base . '&active=progress', false),
+			'Student progress successfully updated!',
+			'passed'
+		);
+		return;
 	}
 }
