@@ -115,7 +115,7 @@ class plgGroupsBlog extends Hubzero_Plugin
 			$group_plugin_acl = $access[$active];
 
 			//Create user object
-			$juser = JFactory::getUser();
+			$juser =& JFactory::getUser();
 
 			//get the group members
 			$members = $group->get('members');
@@ -170,7 +170,7 @@ class plgGroupsBlog extends Hubzero_Plugin
 			Hubzero_Document::addPluginScript('groups', $this->_name);
 
 			// Append to document the title
-			$document = JFactory::getDocument();
+			$document =& JFactory::getDocument();
 			$document->setTitle($document->getTitle() . ': ' . JText::_('PLG_GROUPS_BLOG'));
 
 			if (is_numeric($this->action)) 
@@ -211,11 +211,10 @@ class plgGroupsBlog extends Hubzero_Plugin
 
 		$filters = array(
 			'scope'    => 'group',
-			'group_id' => $group->get('gidNumber'),
-			'state'    => 'public'
+			'group_id' => $group->get('gidNumber')
 		);
 
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 		if ($juser->get('guest')) 
 		{
 			$filters['state'] = 'public';
@@ -236,65 +235,6 @@ class plgGroupsBlog extends Hubzero_Plugin
 		return $arr;
 	}
 
-	/**
-	 * Parse an SEF URL into its component bits
-	 * stripping out the path leading up to the blog plugin
-	 * 
-	 * @return     string
-	 */
-	private function _parseUrl()
-	{
-		static $path;
-
-		if (!$path)
-		{
-			$juri = JURI::getInstance();
-			$path = $juri->getPath();
-
-			$path = str_replace($juri->base(true), '', $path);
-			$path = str_replace('index.php', '', $path);
-			$path = DS . trim($path, DS);
-
-			$blog = '/groups/' . $this->group->get('cn') . '/blog';
-
-			if ($path == $blog)
-			{
-				$path = array();
-				return $path;
-			}
-
-			$path = ltrim($path, DS);
-			$path = explode('/', $path);
-
-			/*while ($path[0] != 'members' && !empty($path));
-			{
-				array_shift($path);
-			}*/
-			$paths = array();
-			$start = false;
-			foreach ($path as $bit)
-			{
-				if ($bit == 'groups' && !$start)
-				{
-					$start = true;
-					continue;
-				}
-				if ($start)
-				{
-					$paths[] = $bit;
-				}
-			}
-			if (count($paths) >= 2)
-			{
-				array_shift($paths);  // Remove group cn
-				array_shift($paths);  // Remove 'blog'
-			}
-			$path = $paths;
-		}
-
-		return $path;
-	}
-
 	/**
 	 * Display a list of latest blog entries
 	 * 
@@ -329,24 +269,24 @@ class plgGroupsBlog extends Hubzero_Plugin
 			'scope'      => 'group',
 			'group_id'   => $this->group->get('gidNumber'),
 			'search'     => JRequest::getVar('search',''),
-			'authorized' => false,
-			'state'      => 'public'
+			'authorized' => false
 		);
 
 		// See what information we can get from the path
-		$juri = JURI::getInstance();
+		$juri =& JURI::getInstance();
 		$path = $juri->getPath();
 		if (strstr($path, '/')) 
 		{
-			$bits = $this->_parseUrl();
-
+			$path = str_replace('/groups/' . $this->group->get('cn') . '/blog', '', $path);
+			$path = ltrim($path, DS);
+			$bits = explode('/', $path);
 			$view->filters['year']  = (isset($bits[0])) ? $bits[0] : $view->filters['year'];
 			$view->filters['month'] = (isset($bits[1])) ? $bits[1] : $view->filters['month'];
 		}
 
 		$view->canpost = $this->_getPostingPermissions();
 
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 		if ($juser->get('guest')) 
 		{
 			$view->filters['state'] = 'public';
@@ -361,12 +301,10 @@ class plgGroupsBlog extends Hubzero_Plugin
 			}
 			else
 			{
-				if ($this->authorized == 'member'
-				 || $this->authorized == 'manager' 
+				if ($this->authorized == 'manager' 
 				 || $this->authorized == 'admin')
 				{
 					$view->filters['authorized'] = true;
-					$view->filters['state'] = 'all';
 				}
 				else
 				{
@@ -405,7 +343,7 @@ class plgGroupsBlog extends Hubzero_Plugin
 		include_once(JPATH_ROOT . DS . 'libraries' . DS . 'joomla' . DS . 'document' . DS . 'feed' . DS . 'feed.php');
 
 		// Set the mime encoding for the document
-		$jdoc = JFactory::getDocument();
+		$jdoc =& JFactory::getDocument();
 		$jdoc->setMimeEncoding('application/rss+xml');
 
 		// Start a new feed object
@@ -431,16 +369,17 @@ class plgGroupsBlog extends Hubzero_Plugin
 		$path = JURI::getInstance()->getPath();
 		if (strstr($path, '/')) 
 		{
-			$bits = $this->_parseUrl();
-
+			$path = str_replace('/groups/' . $this->group->get('cn') . '/blog', '', $path);
+			$path = trim($path, DS);
+			$bits = explode('/', $path);
 			$filters['year']  = (isset($bits[0])) ? $bits[0] : $filters['year'];
 			$filters['month'] = (isset($bits[1])) ? $bits[1] : $filters['month'];
 		}
 
 		// Build some basic RSS document information
-		$jconfig = JFactory::getConfig();
+		$jconfig =& JFactory::getConfig();
 		$doc->title       = $jconfig->getValue('config.sitename') . ': ' . JText::_('Groups') . ': ' . stripslashes($this->group->get('description')) . ': ' . JText::_('Blog');
-		$doc->description = JText::sprintf('PLG_GROUPS_BLOG_RSS_DESCRIPTION', $this->group->get('cn'), $jconfig->getValue('config.sitename'));
+		$doc->description = JText::sprintf('PLG_GROUPS_BLOG_RSS_DESCRIPTION', $jconfig->getValue('config.sitename'));
 		$doc->copyright   = JText::sprintf('PLG_GROUPS_BLOG_RSS_COPYRIGHT', date("Y"), $jconfig->getValue('config.sitename'));
 		$doc->category    = JText::_('PLG_GROUPS_BLOG_RSS_CATEGORY');
 
@@ -540,8 +479,8 @@ class plgGroupsBlog extends Hubzero_Plugin
 			$path = JURI::getInstance()->getPath();
 			if (strstr($path, '/')) 
 			{
-				$bits = $this->_parseUrl();
-
+				$path = str_replace('/groups/' . $this->group->get('cn') . '/blog/', '', $path);
+				$bits = explode('/', $path);
 				$alias = end($bits);
 			}
 
@@ -554,7 +493,7 @@ class plgGroupsBlog extends Hubzero_Plugin
 		}
 
 		// Check authorization
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 		if (($view->row->get('state') == 2 && $juser->get('guest'))
 		 || ($view->row->get('state') == 0 && $juser->get('id') != $view->row->get('created_by') && $this->authorized != 'member' && $this->authorized != 'manager' && $this->authorized != 'admin')) 
 		{
@@ -609,8 +548,8 @@ class plgGroupsBlog extends Hubzero_Plugin
 	 */
 	private function _edit($row=null)
 	{
-		$juser = JFactory::getUser();
-		$app = JFactory::getApplication();
+		$juser =& JFactory::getUser();
+		$app =& JFactory::getApplication();
 		$blog = JRoute::_('index.php?option=' . $this->option . '&cn=' . $this->group->get('cn') . '&active=' . $this->_name);
 
 		if ($juser->get('guest')) 
@@ -619,11 +558,16 @@ class plgGroupsBlog extends Hubzero_Plugin
 			$app->redirect('/login?return=' . base64_encode($blog));
 		}
 
-		if (!$this->authorized || !$this->_getPostingPermissions()) 
+		if (!$this->authorized) 
 		{
-			$app->enqueueMessage(JText::_('PLG_GROUPS_BLOG_ERROR_PERMISSION_DENIED'), 'error');
+			$app->enqueueMessage(JText::_('You are not authorized to edit this blog entry.'), 'error');
+			$app->redirect($blog);
+		}
+
+		if (!$this->_getPostingPermissions()) 
+		{
+			$app->enqueueMessage(JText::_('You do not have permission to post entries.'), 'error');
 			$app->redirect($blog);
-			return;
 		}
 
 		// Instantiate view
@@ -683,18 +627,11 @@ class plgGroupsBlog extends Hubzero_Plugin
 	 */
 	private function _save()
 	{
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 		if ($juser->get('guest')) 
 		{
-			$blog = JRoute::_('index.php?option=' . $this->option . '&cn=' . $this->group->get('cn') . '&active=' . $this->_name);
-	
-			$application = JFactory::getApplication();
-			$application->redirect(
-				'/login?return=' . base64_encode($blog),
-				JText::_('GROUPS_LOGIN_NOTICE'),
-				'warning'
-			);
-			return;
+			$this->setError(JText::_('GROUPS_LOGIN_NOTICE'));
+			return $this->_login();
 		}
 
 		if (!$this->authorized) 
@@ -705,25 +642,12 @@ class plgGroupsBlog extends Hubzero_Plugin
 
 		if (!$this->_getPostingPermissions()) 
 		{
-			$this->setError(JText::_('PLG_GROUPS_BLOG_ERROR_PERMISSION_DENIED'));
+			$this->setError(JText::_('You do not have permission to edit/save entries.'));
 			return $this->_browse();
 		}
 
 		$entry = JRequest::getVar('entry', array(), 'post', 'none', 2);
-		
-		if (isset($entry['publish_up']) && $entry['publish_up'] != '')
-		{
-			$entry['publish_up']   = JFactory::getDate($entry['publish_up'], JFactory::getConfig()->get('offset'))->toSql();
-		}
-		
-		if (isset($entry['publish_down']) && $entry['publish_down'] != '')
-		{
-			$entry['publish_down'] = JFactory::getDate($entry['publish_down'], JFactory::getConfig()->get('offset'))->toSql();
-		}
-		
-		// make sure we dont want to turn off comments
-		$entry['allow_comments'] = (isset($entry['allow_comments'])) ? : 0;
-		
+
 		// Instantiate model
 		$row = $this->model->entry($entry['id']);
 
@@ -739,7 +663,7 @@ class plgGroupsBlog extends Hubzero_Plugin
 			$item = $this->model->entry($row->alias);
 			if ($item->get('id'))
 			{
-				$this->setError(JText::_('PLG_GROUPS_BLOG_ERROR_ALIAS_EXISTS'));
+				$this->setError(JText::_('An entry with the alias generated from this title already exists. Please modify the title.'));
 				return $this->_edit($row);
 			}
 		}
@@ -759,7 +683,7 @@ class plgGroupsBlog extends Hubzero_Plugin
 		}
 
 		//return $this->_entry();
-		$app = JFactory::getApplication();
+		$app =& JFactory::getApplication();
 		$app->redirect(JRoute::_($row->link()));
 	}
 
@@ -770,7 +694,7 @@ class plgGroupsBlog extends Hubzero_Plugin
 	 */
 	private function _delete()
 	{
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 		if ($juser->get('guest')) 
 		{
 			$this->setError(JText::_('GROUPS_LOGIN_NOTICE'));
@@ -785,7 +709,7 @@ class plgGroupsBlog extends Hubzero_Plugin
 
 		if (!$this->_getPostingPermissions()) 
 		{
-			$this->setError(JText::_('PLG_GROUPS_BLOG_ERROR_PERMISSION_DENIED'));
+			$this->setError(JText::_('You do not have permission to delete entries.'));
 			return $this->_browse();
 		}
 
@@ -856,18 +780,11 @@ class plgGroupsBlog extends Hubzero_Plugin
 	private function _savecomment()
 	{
 		// Ensure the user is logged in
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 		if ($juser->get('guest')) 
 		{
-			$blog = JRoute::_('index.php?option=' . $this->option . '&cn=' . $this->group->get('cn') . '&active=' . $this->_name);
-	
-			$application = JFactory::getApplication();
-			$application->redirect(
-				'/login?return=' . base64_encode($blog),
-				JText::_('GROUPS_LOGIN_NOTICE'),
-				'warning'
-			);
-			return;
+			$this->setError(JText::_('GROUPS_LOGIN_NOTICE'));
+			return $this->_login();
 		}
 
 		// Incoming
@@ -899,7 +816,7 @@ class plgGroupsBlog extends Hubzero_Plugin
 	private function _deletecomment()
 	{
 		// Ensure the user is logged in
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 		if ($juser->get('guest')) 
 		{
 			$this->setError(JText::_('GROUPS_LOGIN_NOTICE'));
@@ -936,7 +853,7 @@ class plgGroupsBlog extends Hubzero_Plugin
 	 */
 	private function _settings()
 	{
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 		if ($juser->get('guest')) 
 		{
 			$this->setError(JText::_('GROUPS_LOGIN_NOTICE'));
@@ -987,7 +904,7 @@ class plgGroupsBlog extends Hubzero_Plugin
 	 */
 	private function _savesettings()
 	{
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 		if ($juser->get('guest')) 
 		{
 			$this->setError(JText::_('GROUPS_LOGIN_NOTICE'));
@@ -1011,15 +928,13 @@ class plgGroupsBlog extends Hubzero_Plugin
 
 		// Get parameters
 		$paramsClass = 'JParameter';
-		$mthd = 'bind';
 		if (version_compare(JVERSION, '1.6', 'ge'))
 		{
 			$paramsClass = 'JRegistry';
-			$mthd = 'loadArray';
 		}
 
 		$p = new $paramsClass('');
-		$p->$mthd(JRequest::getVar('params', '', 'post'));
+		$p->bind(JRequest::getVar('params', '', 'post'));
 
 		$row->params = $p->toString();
 
@@ -1039,8 +954,8 @@ class plgGroupsBlog extends Hubzero_Plugin
 
 		//$this->message = JText::_('Settings successfully saved!');
 		//return $this->_settings();
-		$app = JFactory::getApplication();
-		$app->enqueueMessage(JText::_('PLG_GROUPS_BLOG_SETTINGS_SAVED'), 'passed');
+		$app =& JFactory::getApplication();
+		$app->enqueueMessage('Settings successfully saved!', 'passed');
 		$app->redirect(JRoute::_('index.php?option=com_groups&cn=' . $this->group->get('cn') . '&active=' . $this->_name . '&action=settings'));
 	}
 
@@ -1050,7 +965,7 @@ class plgGroupsBlog extends Hubzero_Plugin
 	 * @param      string $text
 	 * @return     string
 	 */
-	/*public static function stripWiki($text)
+	public static function stripWiki($text)
 	{
 		$wiki = array(
 			"'''",   // <strong>
@@ -1073,5 +988,5 @@ class plgGroupsBlog extends Hubzero_Plugin
 		$stripped_text = str_replace($wiki, '', $stripped_text);
 
 		return nl2br($stripped_text);
-	}*/
+	}
 }
