@@ -111,7 +111,7 @@ class plgResourcesUsage extends JPlugin
 		}
 
 		// Check if we have a needed database table
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 
 		$tables = $database->getTableList();
 		$table  = $database->getPrefix() . 'resource_stats_tools';
@@ -197,16 +197,16 @@ class plgResourcesUsage extends JPlugin
 
 		if ($rtrn == 'all' || $rtrn == 'metadata') 
 		{
-			if (!$stats->users)
-			{
-				$stats->users = 0;
-			}
 			if ($model->isTool()) 
 			{
 				$arr['metadata'] = '<p class="usage"><a href="' . $url . '">' . JText::sprintf('PLG_RESOURCES_USAGE_NUM_USERS', $stats->users) . '</a></p>';
 			} 
 			else 
 			{
+				if (!$stats->users)
+				{
+					$stats->users = 0;
+				}
 				$arr['metadata'] = '<p class="usage">' . JText::sprintf('%s users', $stats->users) . '</p>';
 			}
 			if ($clusters->users && $clusters->classes) 
@@ -224,7 +224,7 @@ class plgResourcesUsage extends JPlugin
 	 * @param      integer $time Time
 	 * @return     string
 	 */
-	public static function timeUnits($time) 
+	public function timeUnits($time) 
 	{
 		if ($time < 60) 
 		{
@@ -254,7 +254,7 @@ class plgResourcesUsage extends JPlugin
 	 */
 	public static function getOverview($id, $period=1)
 	{
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 
 		$sql = "SELECT * 
 				FROM #__resource_stats_tools 
@@ -276,7 +276,7 @@ class plgResourcesUsage extends JPlugin
 	 */
 	public static function getTopValue($id, $top, $tid, $datetime, $prd=14)
 	{
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 
 		if (!$id || !$tid)
 		{
@@ -307,7 +307,7 @@ class plgResourcesUsage extends JPlugin
 	 */
 	public static function getTid($id, $datetime, $period=14)
 	{
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 
 		$sql = "SELECT t.id FROM #__resource_stats_tools AS t WHERE t.resid = '$id' AND t.period = '" . $period . "' AND t.datetime = '" . $datetime . "-00 00:00:00' ORDER BY t.id LIMIT 1";
 		$database->setQuery($sql);
@@ -400,7 +400,7 @@ class plgResourcesUsage extends JPlugin
 
 		$json = new stdClass;
 
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 
 		$tid = $this->getTid($id, $datetime, $period);
 
